@@ -2,8 +2,9 @@ import getpass
 import glob
 import hashlib
 import os
+import pathlib
 import re
-from datetime import datetime
+from datetime import date, datetime
 from time import sleep
 
 import pygit2
@@ -21,10 +22,18 @@ from textual.widgets import (Button, Input, ListItem, ListView, Select, Static,
 class MemberApp(App):
     """Single app that toggles between a file list and a form while connected to a GitHub fork+push flow."""
 
-    def __init__(self, token: str, original_repo: Repository) -> None:
+    def __init__(
+        self,
+        original_repo: Repository,
+        forked_repo: Repository,
+        token: str,
+        repo_path: str,
+    ) -> None:
         super().__init__()
-        self.token = token
         self.original_repo = original_repo
+        self.forked_repo = forked_repo
+        self.token = token
+        self.repo_path = repo_path
 
     def compose(self) -> ComposeResult:
         # Two main containers: self.list_container for the file list, self.form_container for the form.
@@ -35,23 +44,7 @@ class MemberApp(App):
         yield self.form_container
 
     def on_mount(self) -> None:
-        """Perform setup: do fork if needed, set up UI."""
-        self.forked_repo = self.original_repo.create_fork()
-        self.FORKED_REPO_URL = self.forked_repo.clone_url
-        self.REPO_PATH = user_data_dir(
-            appname="edit-python-pe", appauthor="python.pe"
-        )
-
-        if not os.path.exists(self.REPO_PATH):
-            callbacks = pygit2.callbacks.RemoteCallbacks(
-                credentials=pygit2.UserPass(self.token, "x-oauth-basic")
-            )
-            sleep(3)
-            pygit2.clone_repository(
-                self.FORKED_REPO_URL, self.REPO_PATH, callbacks=callbacks
-            )
-
-        # 2) Build the list portion
+        # 1) Build the list portion
         self.list_title = Static("Archivos en 'blog/members':")
         self.list_view = ListView()
         self.quit_list_button = Button("Salir", id="quit_list")
@@ -63,28 +56,23 @@ class MemberApp(App):
         self.list_container.mount(self.quit_list_button)
 
         md_files = glob.glob(
-            os.path.join(self.REPO_PATH, "blog", "members", "*.md")
+            os.path.join(self.repo_path, "blog", "members", "*.md")
         )
         for f in md_files:
             basename = os.path.basename(f)
             self.list_view.append(ListItem(Static(basename)))
 
-        # 3) Build the form portion, hidden at first
+        # 2) Build the form portion, hidden at first
         self.form_header = Static("Formulario de Miembro", classes="header")
         self.name_input = Input(placeholder="Nombre")
         self.email_input = Input(placeholder="Correo electrónico")
         self.city_input = Input(placeholder="Ciudad")
         self.homepage_input = Input(placeholder="Página personal")
 
-        self.about_me_area = TextArea(text="Sobre mí")
-        self.who_area = TextArea(text="¿Quién eres y a qué te dedicas?")
-        self.python_area = TextArea(text="¿Cómo programas en Python?")
-        self.contributions_area = TextArea(
-            text="¿Tienes algún aporte a la comunidad de Python?"
-        )
-        self.availability_area = TextArea(
-            text="¿Estás disponible para hacer mentoring, consultorías, charlas?"
-        )
+        self.who_area = TextArea()
+        self.python_area = TextArea()
+        self.contributions_area = TextArea()
+        self.availability_area = TextArea()
 
         self.social_container = Vertical()
         self.alias_container = Vertical()
@@ -95,7 +83,7 @@ class MemberApp(App):
         self.back_button = Button("Atrás", id="back")
         self.quit_button = Button("Salir", id="quit")
 
-        # Mount them in the form container
+        # 3) Mount them in the form container
         self.form_container.mount(self.form_header)
         self.form_container.mount(self.name_input)
         self.form_container.mount(self.email_input)
@@ -112,10 +100,27 @@ class MemberApp(App):
 
         self.form_container.mount(self.city_input)
         self.form_container.mount(self.homepage_input)
-        self.form_container.mount(self.about_me_area)
+        self.form_container.mount(
+            Static("¿Quién eres y a qué te dedicas?", classes="subheader")
+        )
         self.form_container.mount(self.who_area)
+        self.form_container.mount(
+            Static("¿Cómo programas en Python?", classes="subheader")
+        )
         self.form_container.mount(self.python_area)
+        self.form_container.mount(
+            Static(
+                "¿Tienes algún aporte a la comunidad de Python?",
+                classes="subheader",
+            )
+        )
         self.form_container.mount(self.contributions_area)
+        self.form_container.mount(
+            Static(
+                "¿Estás disponible para hacer mentoring, consultorías, charlas?",
+                classes="subheader",
+            )
+        )
         self.form_container.mount(self.availability_area)
 
         self.form_button_bar = Horizontal(
@@ -149,11 +154,10 @@ class MemberApp(App):
         self.email_input.value = ""
         self.city_input.value = ""
         self.homepage_input.value = ""
-        self.about_me_area.text = "Sobre mí"
-        self.who_area.text = "¿Quién eres y a qué te dedicas?"
-        self.python_area.text = "¿Cómo programas en Python?"
-        self.contributions_area.text = "¿Tienes algún aporte a la comunidad de Python?"
-        self.availability_area.text = "¿Estás disponible para hacer mentoring, consultorías, charlas?"
+        self.who_area.text = ""
+        self.python_area.text = ""
+        self.contributions_area.text = ""
+        self.availability_area.text = ""
 
         for soc in self.social_entries:
             soc.remove()
@@ -178,14 +182,14 @@ class MemberApp(App):
         self.show_form()
 
     def load_file_into_form(self, filename: str) -> None:
-        path_md = os.path.join(self.REPO_PATH, "blog", "members", filename)
+        path_md = os.path.join(self.repo_path, "blog", "members", filename)
         if not os.path.exists(path_md):
             return
         try:
-            with open(path_md, "r", encoding="utf-8") as fh:
-                content = fh.read()
+            with open(path_md, "r", encoding="utf-8") as fd:
+                content = fd.read()
         except Exception as e:
-            self.exit(f"Error loading file {filename}: {e}")
+            self.exit(f"Error al leer el archivo {filename}: {e}")
             return
 
         self.clear_form()
@@ -246,13 +250,6 @@ class MemberApp(App):
             self.homepage_input.value = homepage_match.group(1).strip()
 
         # Extract markdown sections under headers
-        sobre_mi_match = re.search(
-            r"## Sobre mí\n(.*?)(?=^### |\Z)",
-            content,
-            re.DOTALL | re.MULTILINE,
-        )
-        if sobre_mi_match:
-            self.about_me_area.text = sobre_mi_match.group(1).strip()
         who_match = re.search(
             r"### ¿Quién eres y a qué te dedicas\?\n(.*?)(?=^### |\Z)",
             content,
@@ -311,6 +308,18 @@ class MemberApp(App):
 
     def add_social_entry(self) -> None:
         class SocialEntry(Horizontal):
+            DEFAULT_CSS = """
+                SocialEntry Select {
+                   width: 25%; 
+                }
+                SocialEntry Input {
+                   width: 50%; 
+                }
+                SocialEntry Button {
+                   width: 25%; 
+                }
+            """
+
             def __init__(se, index):
                 super().__init__()
                 se.index = index
@@ -351,7 +360,16 @@ class MemberApp(App):
             found.remove()
 
     def add_alias_entry(self) -> None:
-        class AliasEntryRow(Horizontal):
+        class AliasEntry(Horizontal):
+            DEFAULT_CSS = """
+                AliasEntry Input {
+                   width: 75%; 
+                }
+                AliasEntry Button {
+                   width: 25%; 
+                }
+            """
+
             def __init__(se, index):
                 super().__init__()
                 se.index = index
@@ -362,7 +380,7 @@ class MemberApp(App):
                 yield se.alias_input
                 yield se.delete_btn
 
-        row = AliasEntryRow(self.alias_index)
+        row = AliasEntry(self.alias_index)
         self.alias_index += 1
         self.alias_entries.append(row)
         self.alias_container.mount(row)
@@ -382,7 +400,6 @@ class MemberApp(App):
         email = self.email_input.value.strip()
         city = self.city_input.value.strip()
         homepage = self.homepage_input.value.strip()
-        about_me = self.about_me_area.text.strip()
         who = self.who_area.text.strip()
         python_ = self.python_area.text.strip()
         contributions = self.contributions_area.text.strip()
@@ -407,7 +424,8 @@ class MemberApp(App):
         md_lines = [
             "---",
             "blogpost: true",
-            f"author: {name}",
+            f"date: {date.today().strftime("%d %b, %Y")}",
+            f"author: {get_alias(aliases, name)}",
             f"location: {city}",
             "category: members",
             "language: Español",
@@ -415,8 +433,6 @@ class MemberApp(App):
             "excerpt: 1",
             "---",
             "",
-            "% NOTA: No olvidar poner la fecha de publicación debajo de `blogpost: true`",
-            "",
             f"# {name}",
             "",
             f"```{{gravatar}} {email}",
@@ -456,11 +472,8 @@ class MemberApp(App):
             md_lines.append(f":Homepage: {homepage}")
             md_lines.append("")
 
-        if about_me:
-            md_lines.append("## Sobre mí")
-            md_lines.append("")
-            md_lines.append(about_me)
-            md_lines.append("")
+        md_lines.append("## Sobre mí")
+        md_lines.append("")
 
         if who:
             md_lines.append("### ¿Quién eres y a qué te dedicas?")
@@ -492,109 +505,18 @@ class MemberApp(App):
 
         md_content = "\n".join(md_lines)
 
-        if not self.current_file:
-            # compute name_file
-            if aliases:
-                alias_for_name = aliases[0].lower().replace(" ", "_")
-            else:
-                alias_for_name = name.lower().replace(" ", "_")
-
-            sha_hash = hashlib.sha1(
-                (alias_for_name + email + datetime.now().isoformat()).encode(
-                    "utf-8"
-                )
-            ).hexdigest()[:8]
-            name_file = f"{alias_for_name}-{sha_hash}"
-
-            # Write file
-            file_path = os.path.join(
-                self.REPO_PATH, "blog", "members", f"{name_file}.md"
-            )
-        else:
-            name_file = self.current_file
-            file_path = os.path.join(
-                self.REPO_PATH, "blog", "members", f"{name_file}"
-            )
-        os.makedirs(os.path.dirname(file_path), exist_ok=True)
-        with open(file_path, "w", encoding="utf-8") as f:
-            f.write(md_content)
-
-        # commit & push
-        repo = pygit2.Repository(self.REPO_PATH)
-        rel_path = os.path.relpath(file_path, self.REPO_PATH)
-        repo.index.add(rel_path)
-        repo.index.write()
-        author_sig = pygit2.Signature(
-            name or "Unknown", email or "unknown@email"
+        message = create_pr(
+            md_content,
+            self.current_file,
+            self.repo_path,
+            self.original_repo,
+            self.forked_repo,
+            self.token,
+            aliases,
+            name,
+            email,
         )
-        tree_id = repo.index.write_tree()
-        parents = [] if repo.head_is_unborn else [repo.head.target]
-        commit_msg = (
-            f"Changed {self.current_file}"
-            if self.current_file
-            else f"Added {name_file}.md"
-        )
-        repo.create_commit(
-            "HEAD", author_sig, author_sig, commit_msg, tree_id, parents
-        )
-
-        callbacks = pygit2.callbacks.RemoteCallbacks(
-            credentials=pygit2.UserPass(self.token, "x-oauth-basic")
-        )
-        remote = repo.remotes["origin"]
-        remote.push([repo.head.name], callbacks=callbacks)
-
-        # PR logic
-        pr_title = commit_msg
-        first_alias = aliases[0] if aliases else ""
-        pr_body = (
-            f"Changing an entry to `blog/members` for {name} (alias: {first_alias})."
-            if self.current_file
-            else f"Creating a new entry to `blog/members` for {name} (alias: {first_alias})."
-        )
-        fork_owner = self.forked_repo.owner.login
-        head_branch = f"{fork_owner}:main"
-        base_branch = "main"
-
-        # If editing, retrieve PR by title and push to its branch
-        if self.current_file:
-            # Try to find an open PR with matching title
-            prs = self.original_repo.get_pulls(
-                state="open", sort="created", base=base_branch
-            )
-            pr_found = None
-            for pr in prs:
-                if self.current_file in pr.title:
-                    pr_found = pr
-                    break
-            if pr_found:
-                # Push to the PR branch (simulate, as actual branch logic may differ)
-                remote.push([repo.head.name], callbacks=callbacks)
-                self.exit(
-                    message=f"Archivo {self.current_file} editado, commit y cambios enviados al PR existente."
-                )
-            else:
-                # Otherwise, create a new PR
-                self.original_repo.create_pull(
-                    title=pr_title,
-                    body=pr_body,
-                    head=head_branch,
-                    base=base_branch,
-                )
-                self.exit(
-                    message=f"Archivo {self.current_file} guardado, commit y PR listo."
-                )
-        else:
-            # Otherwise, create a new PR
-            self.original_repo.create_pull(
-                title=pr_title,
-                body=pr_body,
-                head=head_branch,
-                base=base_branch,
-            )
-            self.exit(
-                message=f"Archivo {name_file}.md guardado, commit y PR listo."
-            )
+        self.exit(message=message)
 
     async def on_event(self, event: Event) -> None:
         # catch listview selection
@@ -605,7 +527,7 @@ class MemberApp(App):
 
 
 def get_repo() -> tuple[str, Repository]:
-    token: str = getpass.getpass(
+    token = getpass.getpass(
         "Por favor ingrese su access token personal de GitHub: "
     )
     g = Github(token)
@@ -622,9 +544,200 @@ def get_repo() -> tuple[str, Repository]:
         exit(1)
 
 
+def fork_repo(token: str, original_repo: Repository) -> tuple[str, Repository]:
+    forked_repo = original_repo.create_fork()
+    forked_repo_url = forked_repo.clone_url
+    repo_path = user_data_dir(appname="edit-python-pe", appauthor="python.pe")
+
+    if not os.path.exists(repo_path):
+        callbacks = pygit2.callbacks.RemoteCallbacks(
+            credentials=pygit2.UserPass(token, "x-oauth-basic")
+        )
+        sleep(3)
+        pygit2.clone_repository(
+            forked_repo_url, repo_path, callbacks=callbacks
+        )
+    return repo_path, forked_repo
+
+
+def compute_file_name(aliases: list[str], name: str, email: str) -> str:
+    # compute name_file
+    if aliases:
+        alias_for_name = aliases[0].lower().replace(" ", "_")
+    else:
+        alias_for_name = name.lower().replace(" ", "_")
+
+    sha_hash = hashlib.sha1(
+        (alias_for_name + email + datetime.now().isoformat()).encode("utf-8")
+    ).hexdigest()[:8]
+    return f"{alias_for_name}-{sha_hash}.md"
+
+
+def read_file(file_path: str) -> str:
+    with open(file_path, "r", encoding="utf-8") as fd:
+        return fd.read()
+
+
+def append_file(file_content: str, file_path: str) -> None:
+    os.makedirs(os.path.dirname(file_path), exist_ok=True)
+    with open(file_path, "a", encoding="utf-8") as fd:
+        fd.write(file_content)
+
+
+def write_file(file_content: str, file_path: str) -> None:
+    os.makedirs(os.path.dirname(file_path), exist_ok=True)
+    with open(file_path, "w", encoding="utf-8") as fd:
+        fd.write(file_content)
+
+
+def commit_and_push(
+    repo_path: str,
+    token: str,
+    was_changed: bool,
+    name_file: str,
+    name: str,
+    email: str,
+) -> tuple[
+    str,
+    pygit2.repository.Repository,
+    pygit2.remotes.Remote,
+    pygit2.callbacks.RemoteCallbacks,
+]:
+    repo = pygit2.repository.Repository(repo_path)
+    repo.index.add_all()
+    repo.index.write()
+    author_sig = pygit2.Signature(name or "Unknown", email or "unknown@email")
+    tree_id = repo.index.write_tree()
+    parents = [] if repo.head_is_unborn else [repo.head.target]
+    commit_msg = (
+        f"Changed {name_file}" if was_changed else f"Added {name_file}"
+    )
+    repo.create_commit(
+        "HEAD", author_sig, author_sig, commit_msg, tree_id, parents
+    )
+
+    callbacks = pygit2.callbacks.RemoteCallbacks(
+        credentials=pygit2.UserPass(token, "x-oauth-basic")
+    )
+    remote = repo.remotes["origin"]
+    remote.push([repo.head.name], callbacks=callbacks)
+    return commit_msg, repo, remote, callbacks
+
+
+def get_alias(aliases: list[str], name: str) -> str:
+    if aliases:
+        return aliases[0]
+    return name
+
+
+def create_member_file(
+    file_content: str,
+    current_file: str | None,
+    repo_path: str,
+    aliases: list[str],
+    name: str,
+    email: str,
+) -> tuple[str, str]:
+    # Name the file
+    name_file = (
+        current_file
+        if current_file is not None
+        else compute_file_name(aliases, name, email)
+    )
+
+    # Write file
+    file_path = os.path.join(repo_path, "blog", "members", name_file)
+    write_file(file_content, file_path)
+    return name_file, file_path
+
+
+def write_authors_file(
+    repo_path: str, aliases: list[str], name: str, email: str
+):
+    file_path = os.path.join(repo_path, "AUTHORS")
+    contents = read_file(file_path)
+    file_content = f"\n{name}({get_alias(aliases, name)}) <{email}>"
+    if file_content.strip() not in contents:
+        append_file(file_content, file_path)
+
+
+def create_pr(
+    file_content: str,
+    current_file: str | None,
+    repo_path: str,
+    original_repo: Repository,
+    forked_repo: Repository,
+    token: str,
+    aliases: list[str],
+    name: str,
+    email: str,
+) -> str:
+    name_file, file_path = create_member_file(
+        file_content, current_file, repo_path, aliases, name, email
+    )
+    write_authors_file(repo_path, aliases, name, email)
+
+    # commit & push
+    commit_msg, repo, remote, callbacks = commit_and_push(
+        repo_path,
+        token,
+        current_file is not None,
+        name_file,
+        name,
+        email,
+    )
+
+    # PR logic
+    pr_title = commit_msg
+    first_alias = aliases[0] if aliases else ""
+    pr_body = (
+        f"Changing an entry to `blog/members` for {name} (alias: {first_alias})."
+        if current_file
+        else f"Creating a new entry to `blog/members` for {name} (alias: {first_alias})."
+    )
+    fork_owner = forked_repo.owner.login
+    head_branch = f"{fork_owner}:main"
+    base_branch = "main"
+
+    # If editing, retrieve PR by title and push to its branch
+    if current_file:
+        # Try to find an open PR with matching title
+        prs = original_repo.get_pulls(
+            state="open", sort="created", base=base_branch
+        )
+        pr_found = None
+        for pr in prs:
+            if current_file in pr.title:
+                pr_found = pr
+                break
+        if pr_found:
+            # Push to the PR branch (simulate, as actual branch logic may differ)
+            remote.push([repo.head.name], callbacks=callbacks)
+            return f"Archivo {name_file} editado, commit y cambios enviados al PR existente."
+        else:
+            # Otherwise, create a new PR
+            original_repo.create_pull(
+                title=pr_title,
+                body=pr_body,
+                head=head_branch,
+                base=base_branch,
+            )
+            return f"Archivo {name_file} guardado, commit y PR listo."
+    else:
+        # Otherwise, create a new PR
+        original_repo.create_pull(
+            title=pr_title,
+            body=pr_body,
+            head=head_branch,
+            base=base_branch,
+        )
+        return f"Archivo {name_file} guardado, commit y PR listo."
+
+
 def main() -> None:
     token, original_repo = get_repo()
-    app = MemberApp(token=token, original_repo=original_repo)
+    repo_path, forked_repo = fork_repo(token, original_repo)
+    app = MemberApp(original_repo, forked_repo, token, repo_path)
     app.run()
 
 
